==> slices_cli-0.1.82rc1-py3-none-any.whl: slices_cli/bi_context.py <==
"""BI CLI."""

from dataclasses import dataclass
from functools import cached_property

import typer
from slices_expauth_client.models.experiment import Experiment

from . import err_console
from .context import ContextObj


@dataclass
class BIContextObj(ContextObj):
    """BI Context object."""

    site_id: str
    cluster_id: str

    def _require_project_id(self):
        project_id = self.get_current_project_id()
        if not project_id:
            err_console.print("[bold red]No project set. " "Please set a project with `slices project use <name>`. :x:")
            raise typer.Exit(1)
        return project_id

    @cached_property
    def bi_flavors_api(self):
        """BI Flavors API."""
        return self.api.get_bi_flavors_api(self.site_id, self._require_project_id())

    @cached_property
    def bi_tasks_api(self):
        """BI Tasks API."""
        return self.api.get_bi_tasks_api(self.site_id, self._require_project_id())

    @cached_property
    def bi_image_api(self):
        """BI Disk Image API."""
        return self.api.get_bi_images_api(self.site_id, self._require_project_id())

    def get_bi_resources_api_by_experiment(self, experiment: Experiment):
        """BI Resources API."""
        return self.api.get_bi_resources_api(self.site_id, self.api.get_experiment_jwt(experiment.id))

    def get_orchestrator_api_by_experiment(self, experiment: Experiment):
        """BI Orchestrator API."""
        return self.api.get_orchestrator_api(self.api.get_experiment_jwt(experiment.id))


class BIContext(typer.Context):
    """Custom context for slices-cli."""

    obj: BIContextObj

==> slices_cli-0.2.0b5-py3-none-any.whl: slices_cli/bi_context.py <==
"""BI CLI."""

from dataclasses import dataclass
from functools import cached_property

import typer
from slices_bi_client.experiment import Experiment

from . import err_console
from .context import ContextObj


@dataclass
class BIContextObj(ContextObj):
    """BI Context object."""

    site_id: str
    cluster_id: str

    def _require_project_id(self):
        project_id = self.get_current_project_id()
        if not project_id:
            err_console.print("[bold red]No project set. " "Please set a project with `slices project use <name>`. :x:")
            raise typer.Exit(1)
        return project_id

    @cached_property
    def bi_flavors_api(self):
        """BI Flavors API."""
        return self.api.for_project(self._require_project_id()).bi(self.site_id).flavor

    @cached_property
    def bi_tasks_api(self):
        """BI Tasks API."""
        return self.api.for_project(self._require_project_id()).bi(self.site_id).task

    @cached_property
    def bi_image_api(self):
        """BI Disk Image API."""
        return self.api.for_project(self._require_project_id()).bi(self.site_id).image

    def get_bi_resources_api_by_experiment(self, experiment: Experiment):
        """BI Resources API."""
        return self.api.for_experiment(experiment.id, self._require_project_id()).bi(self.site_id).resources

    def get_orchestrator_api_by_experiment(self, experiment: Experiment):
        """BI Orchestrator API."""
        return self.api.for_experiment(experiment.id, self._require_project_id()).bi_orchestrator.resources


class BIContext(typer.Context):
    """Custom context for slices-cli."""

    obj: BIContextObj
